.. _overview:

Code Overview
=============

Here you will find an overview of PRAW's objects and methods, but not the
objects attributes which are generated dynamically from reddit's responses and
are thus impossible to accurately describe statically. In :ref:`writing_a_bot`
there is a longer discussion of how to introspect PRAW, which you can use in
conjunction with this nice visual overview.

:mod:`praw` Package
-------------------

.. automodule:: praw.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`objects` Module
---------------------

.. automodule:: praw.objects
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`helpers` Module
---------------------

.. automodule:: praw.helpers
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`errors` Module
--------------------

.. automodule:: praw.errors
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`decorators` Module
------------------------

.. automodule:: praw.decorators
    :members:
    :undoc-members:
    :show-inheritance:
